#
# spec file for package python-jeepney
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-jeepney
Version:        0.8.0
Release:        150400.5.3.1
Summary:        Low-level, pure Python DBus protocol wrapper
License:        MIT
Group:          Development/Languages/Python
URL:            https://gitlab.com/takluyver/jeepney
Source:         https://files.pythonhosted.org/packages/source/j/jeepney/jeepney-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testpath}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This is a low-level, pure Python DBus protocol client. It has an I/O-free
core, and integration modules for different event loops.

%prep
%setup -q -n jeepney-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest jeepney/tests

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Sat Jun  4 2022 dmueller@suse.com
- update to 0.8.0:
  * Removed ``jeepney.integrate`` APIs, which were deprecated in 0.7. Use
    ``jeepney.io`` instead (see :doc:`integrate`).
  * Removed deprecated ``jeepney.io.tornado`` API. Tornado now uses the asyncio
    event loop, so you can use it along with ``jeepney.io.asyncio``.
  * Deprecated ``conn.router`` attribute in the :doc:`api/blocking` integration.
    Use :ref:`proxies <msggen_proxies>` or :meth:`~.blocking.DBusConnection.send_and_get_reply`
    to find   replies to method calls, and :meth:`~.blocking.DBusConnection.filter`
    for other routing.
  * Added docs page with background on D-Bus (:doc:`dbus-background`).
* Tue Sep  7 2021 dmueller@suse.com
- update to 0.7.1:
  * Add ``async with`` support to :class:`~.asyncio.DBusConnection` in the
    asyncio integration.
  * Fix calling :meth:`~.asyncio.DBusConnection.receive` immediately after opening
    a connection in the asyncio integration.
* Sat Jul 17 2021 dmueller@suse.com
- update to 0.7.0:
  * Support for :ref:`sending and receiving file descriptors <send_recv_fds>`.
    This is available with the blocking, threading and trio integration layers.
  * Deprecated older integration APIs, in favour of new APIs introduced in 0.5.
  * Fixed passing a deque in to :meth:`~.blocking.DBusConnection.filter` in the
    blocking integration API.
* Sun Dec 20 2020 dmueller@suse.com
- uppate to 0.6.0:
  * New method :meth:`~.blocking.DBusConnection.recv_until_filtered` in the
    blocking I/O integration to receive messages until one is filtered into a
    queue.
  * More efficient buffering of received data waiting to be parsed into D-Bus
    messages.
* Thu Nov 26 2020 dmueller@suse.com
- update to 0.5.0:
  * New common scheme for I/O integration - see Connections and Routers.
  * Message.serialise() accepts a serial number, to serialise outgoing messages
  without modifying the message object.
  * Improved documentation, including API docs.
* Mon Mar  9 2020 mcalabkova@suse.com
- Update to 0.4.3
  * Raise ConnectionResetError in blocking integration if socket.recv()
    gives no data
* Fri Feb 28 2020 dmueller@suse.com
- update to 0.4.2:
  The blocking ``DBusConnection`` integration class now has a ``.close()``
  method, and can be used as a context manager::
    from jeepney.integrate.blocking import connect_and_authenticate
    with connect_and_authenticate() as connection:
* Wed Sep 11 2019 tchvatal@suse.com
- Update to 0.4.1:
  * Avoid using :class:`asyncio.Future` for the blocking integration.
  * Set the 'destination' field on method return and error messages to the
    'sender' from the parent message.
* Tue Jun 18 2019 mcalabkova@suse.com
- initial packaging (version 0.4)
